Asphalt-redis documentation
===========================

Asphalt-redis provides access to Redis_ databases for Asphalt applications by wrapping the
aioredis_ library. It provides no extra functionality beyond what aioredis_ offers.

.. _Redis: http://redis.io/
.. _aioredis: https://github.com/aio-libs/aioredis

.. toctree::
   :maxdepth: 1

   configuration
   usage
   versionhistory


Indices and tables
==================

* :ref:`API reference <modindex>`
